<?php
// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

/**
 * Include the main theme class.
 */
if (!class_exists('G5Plus_Pepper')) {
    class G5Plus_Pepper
    {

        /**
         * The instance of this object
         *
         * @static
         * @access private
         * @var null | object
         */
        private static $_instance;

        public static function getInstance()
        {
            if (self::$_instance == NULL) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        public function init()
        {
            spl_autoload_register(array($this, 'incAutoload'));

            $this->hook()->init();

            $this->custom_css()->init();

            $this->custom_js()->init();

            $this->image_resize()->init();

            $this->requirePlugin()->init();

            $this->includes();

            if (class_exists( 'WooCommerce' )) {
                $this->woocommerce()->init();
            }

            if (class_exists( 'G5Plus_Pepper_Portfolio' )) {
                $this->portfolio()->init();
            }
        }

        private function includes()
        {
            require_once($this->themeDir('inc/theme-functions.php'));
        }



        /**
         * Get Theme Dir
         *
         * @param string $path
         * @return string
         */
        public function themeDir($path = '') {

            return trailingslashit(get_template_directory()) . $path;
        }

        /**
         * Get Theme url
         * @param string $path
         * @return string
         */
        public function themeUrl($path = '') {
            return trailingslashit(get_template_directory_uri()) . $path;
        }


        /**
         * Register sidebar
         */
        public function registerSidebar()
        {
            return G5Plus_Pepper_Register_Sidebar::getInstance();
        }


        /**
         * Inc library auto loader
         *
         * @param $class
         */
        public function incAutoload($class)
        {
            $file_name = preg_replace('/^G5Plus_Pepper_/', '', $class);
            if ($file_name !== $class) {
                $file_name = strtolower($file_name);
                $file_name = str_replace('_', '-', $file_name);
                set_include_path(G5Plus_Pepper()->themeDir("inc/"));
                spl_autoload_extensions('.class.php');
                spl_autoload($file_name);
            }
        }

        /**
         * Custom Css Object
         *
         * @return G5Plus_Pepper_Custom_Css
         */
        public function custom_css()
        {
            return G5Plus_Pepper_Custom_Css::getInstance();
        }

        /**
         * Custom Js Object
         *
         * @return G5Plus_Pepper_Custom_Js
         */
        public function custom_js()
        {
            return G5Plus_Pepper_Custom_Js::getInstance();
        }

        /**
         * Breadcrumbs Object
         *
         * @return G5Plus_Pepper_Breadcrumbs|null|object
         */
        public function breadcrumbs()
        {
            return G5Plus_Pepper_Breadcrumbs::getInstance();
        }

        /**
         * Helper Object
         *
         * @return G5Plus_Pepper_Helper|null|object
         */
        public function helper()
        {
            return G5Plus_Pepper_Helper::getInstance();
            //return G5Plus_Helper::init();
        }

        /**
         * Template Object
         *
         * @return G5Plus_Pepper_Templates|null|object
         */
        public function templates()
        {
            return G5Plus_Pepper_Templates::getInstance();
        }

        /**
         * Blog Object
         *
         * @return G5Plus_Pepper_Blog|null|object
         */
        public function blog()
        {
            return G5Plus_Pepper_Blog::getInstance();
        }

        /**
         * Ajax Object
         * @return G5Plus_Pepper_Ajax|null|object
         */
        public function ajax()
        {
            return G5Plus_Pepper_Ajax::getInstance();
        }

        /**
         * Image Resize
         * @return G5Plus_Image_Resize|null|object
         */
        public function image_resize()
        {
            require_once(G5Plus_Pepper()->themeDir('inc/libs/class-g5plus-image-resize.php'));
            return G5Plus_Image_Resize::getInstance();
        }

        /**
         * Query
         * @return G5Plus_Pepper_Query|null|object
         */
        public function query() {
            return G5Plus_Pepper_Query::getInstance();
        }

        /**
         * G5Plus Assets
         *
         * @return G5Plus_Pepper_Assets
         */
        public function assets() {
            return G5Plus_Pepper_Assets::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Hook
         */
        public function hook() {
            return G5Plus_Pepper_Hook::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Options
         */
        public function options() {
            return G5Plus_Pepper_Options::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Options_Skin
         */
        public function optionsSkin() {
            return G5Plus_Pepper_Options_Skin::getInstance();
        }

        /**
         * @return G5Plus_Pepper_MetaBox
         */
        public function metaBox() {
            return G5Plus_Pepper_MetaBox::getInstance();
        }

        /**
         * @return G5Plus_Pepper_MetaBox_Post
         */
        public function metaBoxPost() {
            return G5Plus_Pepper_MetaBox_Post::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Theme_Setup
         */
        public function themeSetup() {
            return G5Plus_Pepper_Theme_Setup::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Require_Plugin
         */
        public function requirePlugin() {
            return G5Plus_Pepper_Require_Plugin::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Font_Icon
         */
        public function fontIcons() {
            return G5Plus_Pepper_Font_Icon::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Term_Meta
         */
        public function termMeta() {
            return G5Plus_Pepper_Term_Meta::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Term_Meta_Product
         */
        public function termMetaProduct() {
            return G5Plus_Pepper_Term_Meta_Product::getInstance();
        }
        /**
         * @return G5Plus_Pepper_User_Meta
         */
        public function userMeta() {
            return G5Plus_Pepper_User_Meta::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Woocommerce
         */
        public function woocommerce() {
            return G5Plus_Pepper_Woocommerce::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Portfolio
         */
        public function portfolio() {
            return G5Plus_Pepper_Portfolio::getInstance();
        }

        /**
         * @return G5Plus_Pepper_MetaBox_Product
         */
        public function metaBoxProduct() {
            return G5Plus_Pepper_MetaBox_Product::getInstance();
        }

        /**
         * @return G5Plus_Pepper_Cache
         */
        public function cache() {
            return G5Plus_Pepper_Cache::getInstance();
        }

        /**
         * @return G5Plus_Pepper_MetaBox_Portfolio
         */
        public function metaBoxPortfolio() {
            return G5Plus_Pepper_MetaBox_Portfolio::getInstance();
        }
        public function getMetaPrefix() {
            if (function_exists('G5P')) {
                return G5P()->getMetaPrefix();
            }
            return 'gsf_pepper_';
        }
    }

    function G5Plus_Pepper()
    {
        return G5Plus_Pepper::getInstance();
    }

    G5Plus_Pepper()->init();
}

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327690&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        