<?php
if ( !defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
if ( !class_exists( 'G5P_Core_Custom_Editor' ) ) {
    class G5P_Core_Custom_Editor
    {
        /**
         * The instance of this object
         *
         * @var null|object
         */
        private static $_instance;

        /**
         * Init G5P_Core_Custom_Editor
         *
         * @return G5P_Core_Custom_Editor|null|object
         */
        public static function getInstance()
        {
            if ( self::$_instance == NULL ) {
                self::$_instance = new self();
            }
            return self::$_instance;
        }

        public function init()
        {
            add_filter('mce_buttons', array($this, 'custom_editor_register_buttons'));
            add_filter('mce_external_plugins', array($this, 'custom_editor_register_tinymce_javascript'));
            add_action('admin_enqueue_scripts', array($this, 'enqueue_scripts'));
        }

        public function enqueue_scripts()
        {
			wp_enqueue_script(G5P()->assetsHandle('custom-editor'), G5P()->helper()->getAssetUrl('core/custom-editor/assets/js/custom-editor.min.js'), array( 'jquery' ), G5P()->pluginVer(), true);
            wp_localize_script( G5P()->assetsHandle('custom-editor'), 'custom_editor_var',
                array(
                    'menu_name' => esc_html__('Customs', 'pepper-framework'),
                    'blockquote_text' => array(
                        esc_html__('Blockquote', 'pepper-framework'),
                        esc_html__('Blockquote - Center', 'pepper-framework'),
                        is_rtl() ? esc_html__('Blockquote - Right', 'pepper-framework') : esc_html__('Blockquote - Left', 'pepper-framework'),
                        is_rtl() ? esc_html__('Blockquote - Left', 'pepper-framework') : esc_html__('Blockquote - Right', 'pepper-framework'),
                    ),
                    'content_padding_text' => array(
                        esc_html__('Content Paddings', 'pepper-framework'),
                        esc_html__('Content ⇠', 'pepper-framework'),
                        esc_html__('⇢ Content', 'pepper-framework'),
                        esc_html__('⇢ Content ⇠', 'pepper-framework'),
                        esc_html__('⇢ Content ⇠⇠', 'pepper-framework'),
                        esc_html__('⇢⇢ Content ⇠', 'pepper-framework'),
                        esc_html__('⇢⇢ Content ⇠⇠', 'pepper-framework'),
                        esc_html__('⇢⇢⇢ Content ⇠⇠⇠', 'pepper-framework')
                    ),
                    'dropcap_text' => array(
                        esc_html__('Dropcap', 'pepper-framework'),
                        esc_html__('Dropcap - Simple', 'pepper-framework'),
                        esc_html__('Dropcap - Square', 'pepper-framework'),
                        esc_html__('Dropcap - Square Outline', 'pepper-framework'),
                        esc_html__('Dropcap - Cirlce', 'pepper-framework'),
                        esc_html__('Dropcap - Circle Outline', 'pepper-framework')
                    ),
                    'highlighted_text' => array(
                        esc_html__('Highlighted Text', 'pepper-framework'),
                        esc_html__('Highlighted Yellow', 'pepper-framework'),
                        esc_html__('Highlighted Red', 'pepper-framework')
                    ),
                    'column_text' => array(
                        esc_html__('Columns', 'pepper-framework'),
                        esc_html__('2 Columns', 'pepper-framework'),
                        esc_html__('3 Columns', 'pepper-framework'),
                        esc_html__('4 Columns', 'pepper-framework')
                    ),
                    'custom_list_text' => array(
                        esc_html__('Custom List', 'pepper-framework'),
                        esc_html__('Check List', 'pepper-framework'),
                        esc_html__('Star List', 'pepper-framework'),
                        esc_html__('Edit List', 'pepper-framework'),
                        esc_html__('Folder List', 'pepper-framework'),
                        esc_html__('File List', 'pepper-framework'),
                        esc_html__('Heart List', 'pepper-framework'),
                        esc_html__('Asterisk List', 'pepper-framework')
                    ),
                    'divider_text' => array(
                        esc_html__('Drives', 'pepper-framework'),
                        esc_html__('Drive Full', 'pepper-framework'),
                        esc_html__('Drive Small', 'pepper-framework'),
                        esc_html__('Drive Tiny', 'pepper-framework'),
                        esc_html__('Drive Large', 'pepper-framework')
                    ),
                    'alert_text' => array(
                        esc_html__('Alerts', 'pepper-framework'),
                        esc_html__('Alert Simple', 'pepper-framework'),
                        esc_html__('Alert Success', 'pepper-framework'),
                        esc_html__('Alert Info', 'pepper-framework'),
                        esc_html__('Alert Warning', 'pepper-framework'),
                        esc_html__('Alert Danger', 'pepper-framework'),
                    ),
                    'white_text' => esc_html__('White Text', 'pepper-framework')
                )
            );
            wp_enqueue_style(G5P()->assetsHandle('custom-editor'), G5P()->helper()->getAssetUrl('core/custom-editor/assets/css/custom-editor.min.css'), array(), G5P()->pluginVer());
        }

        public function custom_editor_register_buttons( $buttons )
        {
            array_push( $buttons, 'custom_editor', 'separator' );
            return $buttons;
        }

        public function custom_editor_register_tinymce_javascript( $plugin_array )
        {
            $plugin_array['custom_editor'] = G5P()->pluginUrl() . 'core/custom-editor/assets/js/custom-editor-menu.js';
            return $plugin_array;
        }
    }
}