<?php
/**
 * The template for displaying config.php
 *
 * @package WordPress
 * @subpackage pepper
 * @since pepper 1.0
 */
return array(
    'base' => 'gsf_button',
    'name' => esc_html__('Button', 'pepper-framework'),
    'category' => G5P()->shortcode()->get_category_name(),
    'description' => esc_html__('Eye catching button', 'pepper-framework'),
    'icon'        => 'fa fa-bold',
    'params' => array(
        array(
            'type' => 'textfield',
            'heading' => esc_html__('Text', 'pepper-framework'),
            'param_name' => 'title',
            'value' => esc_html__('Text on the button', 'pepper-framework'),
            'admin_label' => true,
        ),
        array(
            'type' => 'vc_link',
            'heading' => esc_html__('URL (Link)', 'pepper-framework'),
            'param_name' => 'link',
            'description' => esc_html__('Add link to button.', 'pepper-framework'),
        ),
        array(
            'type' => 'dropdown',
            'heading' => esc_html__('Style', 'pepper-framework'),
            'description' => esc_html__('Select button display style.', 'pepper-framework'),
            'param_name' => 'style',
            'value' => array(
                esc_html__('Classic', 'pepper-framework') => 'classic',
                esc_html__('Outline', 'pepper-framework') => 'outline',
                esc_html__('Gradient Accent', 'pepper-framework') => 'primary-gradient',
                esc_html__('Link', 'pepper-framework') => 'link',
                esc_html__('Skew', 'pepper-framework') => 'skew'
            ),
            'std' => 'classic',
            'admin_label' => true,
        ),
        array(
            'type' => 'colorpicker',
            'heading' => esc_html__('Border Color', 'pepper-framework'),
            'param_name' => 'border_color',
            'std' => '#fe3d7d',
            'edit_field_class' => 'vc_col-sm-6 vc_column',
            'dependency' => array(
                'element' => 'style',
                'value' => 'skew',
            ),
        ),
        array(
            'type' => 'dropdown',
            'heading' => esc_html__('Shape', 'pepper-framework'),
            'description' => esc_html__('Select button shape.', 'pepper-framework'),
            'param_name' => 'shape',
            'value' => array(
                esc_html__('Rounded', 'pepper-framework') => 'rounded',
                esc_html__('Square', 'pepper-framework') => 'square',
                esc_html__('Round', 'pepper-framework') => 'round',
            ),
            'dependency' => array(
                'element' => 'style',
                'value_not_equal_to' => array('link'),
            ),
            'std' => 'rounded',
        ),
        array(
            'type' => 'dropdown',
            'heading' => esc_html__('Color', 'pepper-framework'),
            'param_name' => 'color',
            'description' => esc_html__('Select button color.', 'pepper-framework'),
            'value' => array(
                esc_html__('Accent', 'pepper-framework') => 'accent',
                esc_html__('Gray', 'pepper-framework') => 'gray',
                esc_html__('Black', 'pepper-framework') => 'black',
                esc_html__('White', 'pepper-framework') => 'white',
                esc_html__('Red', 'pepper-framework') => 'red',
            ),
            'dependency' => array(
                'element' => 'style',
                'value_not_equal_to' => array('primary-gradient'),
            ),
            'std' => 'primary',
            'admin_label' => true,
        ),
        array(
            'type' => 'dropdown',
            'heading' => esc_html__('Size', 'pepper-framework'),
            'param_name' => 'size',
            'description' => esc_html__('Select button display size.', 'pepper-framework'),
            'std' => 'md',
            'value' => array(
                esc_html__('Mini', 'pepper-framework') => 'xs',
                esc_html__('Small', 'pepper-framework') => 'sm',
                esc_html__('Normal', 'pepper-framework') => 'md',
                esc_html__('Large', 'pepper-framework') => 'lg',
            ),
            'admin_label' => true,
        ),
        array(
            'type' => 'dropdown',
            'heading' => esc_html__('Alignment', 'pepper-framework'),
            'param_name' => 'align',
            'description' => esc_html__('Select button alignment.', 'pepper-framework'),
            'value' => array(
                esc_html__('Inline', 'pepper-framework') => 'inline',
                esc_html__('Left', 'pepper-framework') => 'left',
                esc_html__('Right', 'pepper-framework') => 'right',
                esc_html__('Center', 'pepper-framework') => 'center',
            ),
            'std' => 'inline',
            'admin_label' => true,
        ),
        array(
            'type' => 'gsf_switch',
            'heading' => esc_html__('Set full width button?', 'pepper-framework'),
            'param_name' => 'button_block',
            'std' => '',
            'dependency' => array(
                'element' => 'align',
                'value_not_equal_to' => 'inline',
            ),
            'admin_label' => true,
        ),

        G5P()->shortcode()->vc_map_add_icon_font(),
        array(
            'type' => 'gsf_button_set',
            'heading' => esc_html__('Icon Alignment', 'pepper-framework'),
            'description' => esc_html__('Select icon alignment.', 'pepper-framework'),
            'param_name' => 'icon_align',
            'value' => array(
                esc_html__('Left', 'pepper-framework') => 'left',
                esc_html__('Right', 'pepper-framework') => 'right',
            ),
            'dependency' => array(
                'element' => 'icon_font',
                'value_not_equal_to' => array(''),
            ),
        ),
        array(
            'type' => 'gsf_switch',
            'heading' => esc_html__('Advanced on click action', 'pepper-framework'),
            'param_name' => 'custom_onclick',
            'std' => '',
            'description' => esc_html__('Insert inline onclick javascript action.', 'pepper-framework'),
        ),
        array(
            'type' => 'textfield',
            'heading' => esc_html__('On click code', 'pepper-framework'),
            'param_name' => 'custom_onclick_code',
            'description' => esc_html__('Enter onclick action code.', 'pepper-framework'),
            'dependency' => array(
                'element' => 'custom_onclick',
                'value' => 'on',
            ),
        ),
        G5P()->shortcode()->vc_map_add_css_animation(),
        G5P()->shortcode()->vc_map_add_animation_duration(),
        G5P()->shortcode()->vc_map_add_animation_delay(),
        G5P()->shortcode()->vc_map_add_extra_class(),
        G5P()->shortcode()->vc_map_add_css_editor(),
        G5P()->shortcode()->vc_map_add_responsive()
    )
);